Page 162 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 162

Home

    dictatorship.
    Having deceived much of the world, especially the
    American people, into believing that Communism is dead

    and that we can now live in peace and brotherhood, the
    Master Conspiracy behind the New World Order is now
    moving rapidly toward establishing an overt world
    dictatorship by way of an all powerful United Nations.

    Because of numerous acts of treason upon the part of
    our leaders, the United Nations is now able to wage war
    around the world. These wars, in the name of peace,
    have already resulted in the killing of hundreds of
    thousands of innocent human beings. The greatest
    support for these wars has come from the United States,
    resulting in America rapidly becoming the most hated
    nation in the world.

    It was never the intention of our Founding Fathers that
    we interfere in the affairs of other nations. George

    x«rT

    Washington especially warned against this. There is no
    place in the Constitution that gives anyone but Congress
    the authority to declare war against any nation. There is
    certainly no legal authority for a group of power-mad
    megalomaniacs to make the U. S. an international

    ar XvT 41nd

    aggressor in order to create a New World Order.

    The Master Conspiracy behind the New World Order
    is also using a more subtle means to conquer the world.
    This method is what some have referred to as the "treaty
    trap." It is just as deadly as war. It employs the age-old
    revolutionary scheme of creating a crisis and then

    157

    U.N. Modern Tower of Babel

    murder of millions of Americans by a Communist style